# Sonos Artwork

Displays Sonos artwork on a HyperPixel 4.0 Square.

Allows for basic playback controls, such as _Previous_, _Play/Pause_, _Next_.

Clicking in the middle of the screen display current track information.

## Requirements

The Sonos HTTP API running somewhere: https://github.com/jishi/node-sonos-http-api

## Limitations

Only work with Sonos Radio and Apple Music.